Registrarse en ForoBeta
Description: Foro de discusión acerca de bloggers, seo, monetización, hospedaje, wordpress, blogger así como otros temas relevantes para los webmasters.
Keywords: foro,blog,wordpress,blogger,seo,adsense,diseño grafico,blogger,joomla,vbulletin,infolinks,hotwords

- Registro
- Recordarme

# Regístrate, es gratis

Usuario:

Ingresa el nombre por el que te gustaría ingresar.

- Contraseña:
- Confirmar contraseña:

Introduce una contraseña para tu cuenta. Se toman en cuenta las minúsculas y las mayúsculas.

- Dirección de correo electrónico:
- Confirmar dirección de correo electrónico:

Escribe una dirección de correo electrónico válida.

Verificación de imagen

### Información adicional requerida (perfil)

Fecha de nacimiento:

- mes
- Día
- Año

Tu fecha de nacimiento y edad son mostrados en varias partes del foro. Solo el administrador tendrá acceso a tu fecha de nacimiento si eliges ocultarla a través de la opción de privacidad abajo.

Privacidad:

### Información Adicional

Referido por:

Si has sido referido a este sitio por un miembro existente de ForoBeta, escribe su nombre aquí.

## Reglas de ForoBeta

Para seguir, debes de estar de acuerdo con las siguientes normas:

Reglas Generales
Temas, mensajería privada y firmas
Actitudes que ameritan una infracción:
1. Mensaje o tema sin sentido.
Dejar un mensaje o un tema que carezca de sentido para el foro o el tema del que se trata.
(10 puntos de infracción / expiración de 15 días)
2. Fuera de foro.
Dejar un tema fuera del foro/subforo correspondiente.
(10 puntos de infracción / expiración de 15 días)
3. Inundación de mensajes (flood).
Escribir gran cantidad de mensajes en poco tiempo con nulo aporte a los temas como agradecimientos u otros mensajes de nulo valor.
(10 puntos de infracción / expiración de 15 días)
4. Creación de temas para solicitar invitaciones, reportar sitios u otros beneficios.
Para solicitar ayuda de los usuarios referente a otras comunidades se debe utilizar el tema "Di lo que quieras" ubicado en el subforo de Fuera de tema.
(10 puntos de infracción / expiración de 15 días)
5. Promoción fuera de lugar.
Promocionar tus blogs está permitido ya sea para responder un tema, hacer mención en di lo que quieras, en presentaciones y al dejar un tutorial agregarlo como fuente, así como en la firma de cada usuario. Fuera de ahí se considera como fuera de lugar.
(10 puntos de infracción / expiración de 15 días)
6. Discriminación.
Discriminar a alguien por su nacionalidad, edad, religión, sexualidad o preferencias personales.
(10 puntos de infracción / expiración de 15 días)
7. Riñas.
Provocar conflictos con comentarios hirientes o actitudes que fomentan descomunión.
(10 puntos de infracción / expiración de 15 días)
8. Lenguaje vulgar.
Utilizar un vocabulario no adecuado para el foro.
(10 puntos de infracción / expiración de 15 días)
9. Enlaces de referidos.
Promover algún sistema de referido desde el foro o desde un enlace/archivo que contenga este; eso se debe promocionar desde los anuncios de los usuarios los que tengan acceso a ellos.
(10 puntos de infracción / expiración de 15 días)
10. Escribir incoherentemente.
Faltas graves ortográficas, colores chillantes, en puras mayúsculas o en estilo hoygan constantemente, además como realizar títulos en el foro que sean incomprensibles.
(10 puntos de infracción / expiración de 15 días)
11. Contenido que vaya en contra de las políticas de Google Adsense: imágenes violentas, pornografía, contenido warez, etc.
Es posible enlazar sitios con contenido warez (no el contenido); los sitios pornográficos, únicamente pueden ser publicados en la sección de negocios con el código BB xxx.
(10 puntos de infracción / expiración de 30 días)
12. Duplicar temas.
Crear temas duplicados para dar a conocer algún suceso, blog o cualquier evento en un plazo corto de tiempo. Reportar para eliminar este tipo de temas en la brevedad posible.
(10 puntos de infracción / expiración de 15 días)
13. Difamación.
Abrir un post exclusivamente para acusar a alguien de estafa o similares, ya sea usuario o no del foro. Para realizar esto es necesario haber calificado negativamente al usuario y hacerlo en el post de venta de su negocio, explicando detalladamente lo sucedido.
(10 puntos de infracción / expiración de 30 días)
14. Ofertas fuera de la sección de negocios.
Crear temas o mensajes negociando cualquier producto o servicio sin ser considerado como un aporte para las secciones generales.
(10 puntos de infracción / expiración de 30 días)
15. Tamaño de imagen en firmas.
El tamaño máximo aceptado en las firmas es de 500x100.
(5 puntos de infracción / expiración de 30 días)
16. Cuentas duplicadas.
El uso de cuentas adicionales por un mismo usuario, favor de notificar al administrador si hay necesidad de usar una cuenta adicional en la misma computadora.
(40 puntos de infracción / expiración: nunca)
17. Spam y otras actividades dañinas para el foro.
Spam de manera automática, ataques constantes contra los usuarios o moderación del foro, así como cualquier actitud que se pueda calificar como una estafa consumada o un intento de esta (si es un intento se deben presentar pruebas a la administración).
(40 puntos de infracción / expiración: nunca)
Reglas de negocios
Actitudes que ameritan una infracción:
18. Desvirtuar negocio.
Dejar un mensaje sin intención de realizar negocio. Se puede dejar una revisión detallada del negocio siempre y cuando se haya calificado en itrader.
(25 puntos de infracción / expiración de 3 días)
19. Datos faltantes/adicionales en la contraoferta.
Dejar un mensaje que no cumpla las especificaciones requeridas por el ofertante.
(25 puntos de infracción / expiración de 3 días)
20. Negocio no solicitado por mensaje privado.
Mandar un mensaje privado con un negocio que no ha sido requerido.
(25 puntos de infracción / expiración de 3 días)
21. Duplicar ofertas o subastas.
Duplicar ofertas o subastas en un plazo de 7 días, el producto debe diferir notablemente para no considerarse como oferta duplicada.
(25 puntos de infracción / expiración de 3 días)
22. Calificación injustificada.
Calificar a otra persona por itrader de manera injustificada.
(25 puntos de infracción / expiración de 30 días)
23. Comerciar con contenido con derechos de autor o artículos robados.
Vender u ofertar por contenido que falte a los derechos de autor como plantillas, programas, cracks, seriales, scripts, cuentas robadas, etc.
(25 puntos de infracción / expiración de 30 días)
24. Dejar oferta de negocios en un tema ajeno.
Dejar una oferta distinta a la requerida por el ofertante en vez de iniciar un tema nuevo.
(25 puntos de infracción / expiración de 3 días)
25. Comerciar con bases de datos.
Comerciar con bases de datos como listas de correos, teléfonos o información que pueda infrinjir la privacidad de terceros.
(25 puntos de infracción / expiración de 3 días)
26. Comerciar con cursos mágicos o que prometan cierta cantidad de ganancias.
Cualquier curso o guía que sea vendido no puede prometer en ningún momento cantidad de ganancias, pero sí puede incluir contenidos del curso y lo que será aprendido.
(25 puntos de infracción / expiración de 30 días)
Reglas de subastas
Actitudes que ameritan una infracción además de cierre del tema:
27. Datos faltantes de subasta de dominio.
Datos que se deben indicar al subastar un dominio (sugerimos utilizarlos al crear los temas para evitar infracciones):

- Dominio:
- Precio inicial de subasta:
- Incremento de pujas:
- Precio de compra directa: (opcional)
- Hora y fecha de finalización de subasta:

(25 puntos de infracción / expiración de 3 días)
28. Datos faltantes de subasta de sitio.
Datos que se deben indicar al subastar un sitio (sugerimos utilizarlos al crear los temas para evitar infracciones):

- Sitio:
- Visitas (diarias, mensuales o anuales):
- Ganancias (diarias, mensuales o anuales):
- Precio inicial de subasta:
- Incremento de pujas:
- Precio de compra directa: (opcional)
- Hora y fecha de finalización de subasta:

(25 puntos de infracción / expiración de 3 días)
29. Datos faltantes de otras subastas.
Datos que se deben indicar en cualquier otro tipo de subastas del foro (sugerimos utilizarlos al crear los temas para evitar infracciones):

- Producto o servicio (descripción detallada):
- Precio inicial de subasta:
- Incremento de pujas:
- Precio de compra directa: (opcional)
- Hora y fecha de finalización de subasta:

(25 puntos de infracción / expiración de 3 días)
30. Ofertar incorrectamente en subasta.
Ofertar menos de lo que sería correcto siguiendo la dinámica de la subasta:

- No respetar el incremento de pujas actual.
- Dejar un precio desfasado.
- Intentar comprar de manera directa cuando no existe tal opción.
- Pujar cuando se ha aclarado que ha terminado la subasta.

(25 puntos de infracción / expiración de 3 días)
31. Subasta realizada en otro sitio.
Subastar algo en el foro y en otro lugar distinto al mismo tiempo.
(25 puntos de infracción / expiración de 3 días)
32. Cancelar subasta sin ofertantes.
Cancelar una subasta antes de cumplir la fecha pactada de finalización o en un plazo menor a siete días (si no hay fecha fija) en caso de no haber ofertantes.
(25 puntos de infracción / expiración de 3 días)
33. Duplicar oferta y subasta.
Vender y subastar al mismo tiempo dentro del foro un mismo producto. Para evitar esto debe reportarse primero que se cierre uno de los temas.
(25 puntos de infracción / expiración de 3 días)
Actitudes que ameritan una infracción además de eliminación del mensaje (se invalida):
34. Cancelar una oferta en una subasta sin ser ganador.
Cancelar una oferta dejada en subasta sin ganarla.
(25 puntos de infracción / expiración de 3 días)
35. Pujas condicionales.
Pujar con condicionales ejemplo: "Oferta en caso de".
(25 puntos de infracción / expiración de 3 días)
36. Modificar una condición de subasta con ofertantes.
Intentar modificar un dato obligatorio en la subasta si ya se encuentran ofertando.
(25 puntos de infracción / expiración de 3 días).
Actitudes que ameritan una infracción y calificación negativa por el usuario afectado (ya sea vendedor o comprador) además de cerrar el tema:
37. Cancelar subasta con ofertantes.
Cancelar una subasta cuando han comenzado a ofertar.
(25 puntos de infracción / expiración de 15 días).
38. Cancelar una oferta en una subasta siendo el ganador.
Cancelar una oferta dejada en subasta ganándola (en este caso el vendedor puede reiniciar la subasta u ofrecer al ofertante anterior sin que este tenga la obligación de comprar).
(25 puntos de infracción / expiración de 15 días).
39. Incumplir con subasta.
Resistirse a cumplir con lo pactado en el mensaje inicial de la subasta.
(25 puntos de infracción / expiración de 15 días).
Los puntos de infracción son acumulables de la siguiente manera:
25 puntos de infracción: Ban de la sección de negocios por 3 días
40 puntos de infracción: Ban general por 2 semanas
He leído, y estoy de acuerdo en cumplir las normas de ForoBeta.